clear
clc
close all
% Get lists of czi files
filenames = dir('*.czi*');


% Find roots (separate fields are of the form sample_name_x.czi where x is
% a number
filenames_str = {filenames(:).name};
filenames_roots = {};
for i = 1:length(filenames_str)
    filenames_roots{i} = filenames_str{i}(1:end-5);
end
% Get list of unique roots
filenames_uniqueRoots = unique(filenames_roots);

for i = 1:length(filenames_uniqueRoots)
    volumes = [];
    % Find strings with this root
    inds = find(strcmp(filenames_roots,filenames_uniqueRoots{i}));
    for j = 1:length(inds)
        % Open images
        [img metadata] = openCZI_tiles(filenames(inds(j)).name);
        % Set threshold (when each threshold is normalized between 0 to 1)
        threshold = 0.25;
        volumes = [volumes; analyzeFile3D(img,threshold)];
    end
    % Remove salt and pepper noise
    volumes(volumes<=2) = [];
    voxelX = double(metadata.getPixelsPhysicalSizeX(0).value(ome.units.UNITS.MICROM));
    voxelY = double(metadata.getPixelsPhysicalSizeY(0).value(ome.units.UNITS.MICROM));
    voxelZ = double(metadata.getPixelsPhysicalSizeZ(0).value(ome.units.UNITS.MICROM));
    scalingFactor = voxelX*voxelY*voxelZ;
    volumes = ceil(volumes.*scalingFactor);
    % Volume weighted average
    volume_weighted_average = sum(volumes.^2)/(sum(volumes));
    % Calculate ECDF
    [x_ECDF,y_ECDF] = calculateECDF_weighted(volumes);
    save(filenames_uniqueRoots{i}(1:end-1),'volumes','volume_weighted_average','x_ECDF','y_ECDF')
    

    
    
end


