clear
clc
close all

filenames = dir('*.czi*');
% List .czi files in console
fprintf('Choose Image File\n')
for i = 1:length(filenames)
    fprintf('%d: %s\n',i,filenames(i).name);
end
% Get user to choose filename
while true
    in = input('Enter Number of Choice\n');
    if in<=length(filenames)
        break
    else
        fprintf('Invalid Input!\n Try Again\n');
    end
end
% Open .czi file and take a maximum z projection to bound search:
[img metadata] = openCZIFile(filenames(in).name);
filename = filenames(in).name;
new_filename = filename(1:end-4);
img4D = img;
% Now identify threshold for analysis
while true
    in = input('Enter Threshold Value\n');
    threshold = in;
%Get a mask for the image based on threshold, and show it
    mask = img4D(:,:,:,1)>=in | img4D(:,:,:,2)>=in;
    oldImg = maxProjectZ(img);
    subplot(1,2,1)
    imshow(oldImg)
    subplot(1,2,2)
    imshow(max(mask,[],3))
%         Ask if this is a good threshold, otherwise retry
    in = input('Good Threshold?, 1 if yes');
    if in==1
        break
    end
end

% Label contiguous blobs and extract relevant parameters 
L = bwlabeln(mask);
stats = regionprops3(L);
% We really only care about the largest aggregate in this analysis:
% Find it, and get a mask for it
areas = [stats.Volume];
[maxArea, ind] = max(areas);
largeAggregate = L==ind;
% Remask original image
largeAggregate4 = cat(4,largeAggregate,largeAggregate);
img4D(~largeAggregate4) = 0;
% Label perimeter pixels in 2D maxprojected image
img_projected = maxProjectZ(img4D);
mask = img_projected(:,:,1)>=threshold | img_projected(:,:,2)>=threshold;
perimeter = bwboundaries(mask,'noholes');
[r c] = size(perimeter);
redPixels = 0;
greenPixels = 0;
perimeterArr = perimeter{1};
% Count pixels of each color on perimeter of projected aggregate
for i = 1:length(perimeterArr)
    if img_projected(perimeterArr(i,1),perimeterArr(i,2),1)>img_projected(perimeterArr(i,1),perimeterArr(i,2),2)
                greenPixels = greenPixels + 1;
    else
                redPixels = redPixels + 1;
    end
end

% Calculate percentage of pixels
fractionGreen = greenPixels/(redPixels+greenPixels);
save_coverage(new_filename,fractionGreen)


                