
clear
clc
close all
% Set all Parameters
%       P(1) = thiele modulus
%       P(2) = BetaHat
%       P(3) = KHat
%       P(4) = Hill coefficient
P{1} = 10;   
P{2} = 5;   
P{3} = 1;  
P{4} = 2;
% Maximum extent is 1 (dimensionless, see derivation)
R = 1;    
% Integrate out to 10 dimensionless time units
maxt = 10;
% Dimensionality (m=2 represents spherical coordinates)
m = 2;
% Generate desired time steps
t= linspace(0,maxt,100);
deltaT = maxt/length(t);
% Initially, we set constant external concentrations at 1.
CA_t = [t' ones(length(t),1)];
P{5} = CA_t;
% Generate grid points
x = linspace(0,R,500);
% Set overall volume fraction of aggregates/cells.
volumeFraction = 5E-4;
P{6} = volumeFraction;

% Call PDEPE matlab function
done = false;
while done==false
    solPDE = pdepe(m,@ReactionDiffusionPDE,@ReactionDiffusionIC,@ReactionDiffusionBC,x,t,[],P); 
    
% Now calculate what the outer concentration would be subject to the inner piece
% Do this by stepping through the time points, and calculating what the net
% flux is at all points (which is integrated production minus integrated accumulation)
for i = 2:length(CA_t)
    % Get the previous and current concentrations inside the aggregate
    CA_r_last = solPDE(i-1,:);
    CA_r = solPDE(i,:);
    % Calculate the instantaneous reaction rates as a function of r (and
    % implicitly of inner concentrations)
    R_A = 1 + P{2}*(CA_r_last).^P{4}/(P{3}.^P{4} + CA_r_last.^P{4});
    r = linspace(0,1,length(CA_r));
    % Calculate net flux
    deltaCA = 4*pi*(trapz(r,r.^2.*R_A).*deltaT - (trapz(r,r.^2.*CA_r)-trapz(r,r.^2.*CA_r_last)));
    % Calculate the next outer concentration
    CA_t(i,2) = CA_t(i-1,2) + volumeFraction*deltaCA;
end
CA_t_last = P{5};
% Check whether the outer concentration from iterating the PDE solution has
% changed. If not then we are done
if abs(CA_t_last(2,end)-CA_t(2,end))<0.0001
    done = true;
end
P{5} =  CA_t;
end

% Solve ODE version
[t1 y] = ode45(@reactionODE,[0 maxt],1,[],P);
%Plot time curves:
for i = 1:length(t)
    CA_r = solPDE(i,:);
    % Average the concentration over the sphere.
    C_average_t(i) = 4*pi*trapz(r,r.^2.*CA_r)/(4/3*pi);
end
hold on
plot(t,C_average_t,'r')


plot(t1,y,'b')
xlabel('Time')
ylabel('Concentration')
legend('Structured','Unstructured')